/**
 * gclc-socket:net.bigeon.gclc.socket.RemoteDisconnectCommandTest.java
 * Created on: Nov 18, 2017
 */
package net.bigeon.gclc.socket;

/*-
 * #%L
 * GCLC Socket
 * %%
 * Copyright (C) 2016 - 2018 Bigeon
 * %%
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 * #L%
 */
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import java.io.IOException;

import org.junit.Test;

import net.bigeon.gclc.exception.CommandRunException;
import net.bigeon.gclc.manager.PipedConsoleOutput;

/**
 * <p>
 * TODO
 *
 * @author Emmanuel Bigeon */
public class RemoteDisconnectCommandTest {

    /** Test method for
     * {@link net.bigeon.gclc.socket.RemoteDisconnectCommand#execute(net.bigeon.gclc.manager.ConsoleOutput, net.bigeon.gclc.manager.ConsoleInput, java.lang.String[])}.
     *
     * @throws CommandRunException if the command unexpectedly failed.
     * @throws IOException if the output could not be written to */
    @Test
    public final void testExecute() throws CommandRunException, IOException {
        final DConnexionManager<String> manager = new DConnexionManager<>();
        final RemoteDisconnectCommand<String> cmd = new RemoteDisconnectCommand<>("quit",
                manager, true);
        final RemoteDisconnectCommand<String> cmd2 = new RemoteDisconnectCommand<>("quit",
                manager, false);
        manager.addConnexion("test");

        cmd2.execute(null, null);
        assertFalse("No arguemnt should remova no connections",
                manager.getConnected().isEmpty());
        cmd.execute(null, null);
        assertTrue("No arguemnt should remova all connections",
                manager.getConnected().isEmpty());

        final String name1 = manager.addConnexion("test");
        final String name2 = manager.addConnexion("test");

        cmd.execute(null, null, name1);
        assertFalse("With argument shuld remove specified name",
                manager.getConnected().contains(name1));
        assertTrue("With argument shuld remove only specified name",
                manager.getConnected().contains(name2));

        cmd.execute(null, null, name1);
        assertTrue("With argument shuld remove only specified name",
                manager.getConnected().contains(name2));

        try (PipedConsoleOutput out = new PipedConsoleOutput()) {
            cmd.execute(out, null, name1);
            assertTrue("With argument shuld remove only specified name",
                    manager.getConnected().contains(name2));

            out.close();
            try {
                cmd.execute(out, null, name1);
                fail("Closed stream should cause error in printing");
            } catch (final CommandRunException e) {
                // ok
            }
        }
    }

}
