/**
 * 
 */
package net.bigeon.gclc.swt;

/*-
 * #%L
 * GCLC swt
 * %%
 * Copyright (C) 2015 - 2018 Bigeon
 * %%
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 * #L%
 */

import java.io.BufferedReader;

import org.eclipse.swt.widgets.Label;

import net.bigeon.gclc.swt.tools.PromptReadingRunnable;

/** The manager for the console prompt updates.
 * 
 * @author Emmanuel Bigeon */
public final class ConsolePromptManager {

    /** The label to set the prompts at. */
    private final Label label;

    /** The current prompt reading runnable. */
    private PromptReadingRunnable promptRead;

    /** Create the manager.
     * 
     * @param label the label to update with prompts */
    public ConsolePromptManager(final Label label) {
        super();
        this.label = label;
    }

    /** Set the prompt.
     * <p>
     * This method sets the prompt on the label as requested, without changing the
     * actual prompt of the console input.
     * 
     * @param string the text */
    public void setPrompt(final String string) {
        label.setText(string);
    }

    /** Set the input to control.
     * 
     * @param promptStream the input */
    public void setStream(final BufferedReader promptStream) {
        if (promptRead != null) {
            if (promptRead.getReader() == promptStream) {
                return;
            }
            promptRead.setRunning(false);
        }
        if (promptStream == null) {
            promptRead = null;
            return;
        }
        promptRead = new PromptReadingRunnable(promptStream, label);
        final Thread th = new Thread(promptRead, "Prompt To Label");
        th.start();
    }
}
